@@ -137,9 +137,11 @@ at minimum. For example:
     'attr_match_list' => [
         'Name',
         'EmailAddress',
-        'RealName',
     ],
 
+You should not use items that can map to multiple users (such as a
+RealName or building name).
+
 =item attr_map
 
 Mapping of RT attributes on to attributes in the external source.
